/*
** File: iprog.c  
** Project: ADB3 API library
** Purpose: OS-independent code for ADB3 API library, IPROG extension.
**
** (C) Copyright Alpha Data 2015
*/

#include <adb3/iprog.h>
#include <portability.h>
#include <adb3_platform.h>
#include "ioctl_adb3.h"

ADB3_EXPORT ADB3_STATUS
ADB3_CALLING_CONVENTION
ADB3_AbortIPROG(
  ADB3_HANDLE hCard,
  unsigned int targetIndex)
{
  IOCTLS_ADB3_ABORTIPROG ioctl;

  ioctl.in.targetIndex = targetIndex;
  return adb3Ioctl(hCard, ADB3_IOCTLCODE_ABORTIPROG, &ioctl, sizeof(ioctl.in), 0);
}

ADB3_EXPORT ADB3_STATUS
ADB3_CALLING_CONVENTION
ADB3_ScheduleIPROG(
  ADB3_HANDLE hCard,
  unsigned int targetIndex,
  _ADB3_UINT32 flags,
  _ADB3_UINT64 address,
  _ADB3_UINT32 delayMs)
{
  IOCTLS_ADB3_SCHEDULEIPROG ioctl;

  ioctl.in.address = address;
  ioctl.in.targetIndex = targetIndex;
  ioctl.in.flags = flags;
  ioctl.in.delayMs = delayMs;
  return adb3Ioctl(hCard, ADB3_IOCTLCODE_SCHEDULEIPROG, &ioctl, sizeof(ioctl.in), 0);
}

ADB3_EXPORT ADB3_STATUS
ADB3_CALLING_CONVENTION
ADB3_StatusIPROG(
  ADB3_HANDLE hCard,
  unsigned int targetIndex,
  _ADB3_UINT32* pFlags,
  _ADB3_UINT64* pAddress,
  _ADB3_UINT32* pDelayMs)
{
  IOCTLS_ADB3_STATUSIPROG ioctl;
  ADB3_STATUS status;

  ioctl.in.targetIndex = targetIndex;
  status = adb3Ioctl(hCard, ADB3_IOCTLCODE_STATUSIPROG, &ioctl, sizeof(ioctl.in), sizeof(ioctl.out));
  if (ADB3_SUCCESS == status) {
    if (NULL != pFlags) {
      *pFlags = ioctl.out.flags;
    }
    if (NULL != pAddress) {
      *pAddress = ioctl.out.address;
    }
    if (NULL != pDelayMs) {
      *pDelayMs = ioctl.out.delayMs;
    }
  }
  return status;
}
